# -*- coding: utf-8 -*-
##------------------------------------------
##  Auto-door control Program  Ver 0.02
##          platform: windows
##
##               2022.08.19 Masahiro Izutsu
##------------------------------------------
## door_ctrl.py
##  ver 0.04    2022.09.15      ポートがない場合の処理追加

import serial

class Door:
    ser = None

    def set_port(self, COM = "COM3", bitRate = 115200):
        try:
            self.ser = serial.Serial(COM, bitRate, timeout=0.1)
            return self.ser
        except:
            return None

    def get_port(self):
        if self.ser is None:
            return None
        else:
            return self.ser.name

    def send_command(self, cmd):
        if self.ser is not None:
            self.ser.write(cmd.encode())

    def info(self):
        if self.ser is not None:
            cmd = f"'{self.ser.name}' port ready."
            self.send_command(cmd)

    def open_door(self):
        cmd = "open"
        self.send_command(cmd)

    def close_door(self):
        cmd = "close"
        self.send_command(cmd)

    def open_close(self):
        cmd = "door"
        self.send_command(cmd)

    def finish(self):
        if self.ser is not None:
            cmd = "quit"
            self.send_command(cmd)
            self.ser.close()

    def read(self):
        if self.ser is not None:
            ln = self.ser.readline()
            return ln.decode()
        else:
            return ''

#-----Test routine-----
def main(COM = 'COM3'):
    from readchar import readchar, key      # UP.DOWN.LEFT,RIGHT 不可(複合キャラクタ)
    import time

    door = Door()
    ser = door.set_port(COM)
    if ser is None:
        print(f"'{COM}' port not found.")
    else:
        print(f"'{COM}' port ready.")

    while True:
        time.sleep(0.05)

        line = door.read()
        if len(line) > 0:
            print(line)

        c = readchar()
        c_utf8 = c.encode("utf-8")
        print(c_utf8)

        if c == 'h':
            door.info()

        elif c == 'o':
            door.open_door()

        elif c == 'c':
            door.close_door()

        elif c == 'd':
            door.open_close()

        elif c == 'q' or c == key.ESC:
            print("Program Finished.")
            door.finish()
            break

# main関数エントリーポイント(実行開始)
# $ python3 door_ctrl.py {option:COM1}
#
if __name__ == "__main__":
    import sys

    args = sys.argv
    COM = 'COM3' if len(args) <= 1 else args[1]
    main(COM)
