# -*- coding: utf-8 -*-
##------------------------------------------
##   Face Recognition Setting   ver 0.01
##          platform: linux / windows
##
##               2022.09.16 Masahiro Izutsu
##------------------------------------------
## face_rec_yaml.py

from os.path import expanduser
import my_yaml

# 定数定義
FACE_YAML_PATH = expanduser('./face_rec.yaml')          # 設定ファイルパス
FACE_REC_SET = '.FaceRec'                               #  セクション名: Face Recognition 
UART_SET = 'UARTport'                                   #               UART
JTALK_SET = 'JTalkVoice'                                #               OpenJTalk
MAIL_SET = 'MailServer'                                 #               SMTPサーバー
KEY_ACCOUNT = 'account'                                 #  キー名:      アカウント
KEY_PASSWORD = 'password'                               #               パスワード
KEY_HOST = 'host'                                       #               ホスト・サーバー
KEY_PORT = 'port'                                       #               ポート
KEY_FROM = 'from'                                       #               送信元
KEY_TO ='to'                                            #               送信先
KEY_VOICE = 'voice'                                     #               音声選択 (0-5)
KEY_ENABLE = 'enable'                                   #               許可 (Yes/No)

KEY_FACE_FOLDER = 'FaceFolder'                          #               登録画像フォルダパス
KEY_TOLERANCE = 'tolerance'                             #               認証しきい値 (0.0〜1.0)文字列
KEY_TILE_FLG = 'TitleDisp'                              #               タイトル表示 (y/n)
KEY_SPEED_FLG = 'SpeedSisp'                             #               F.P.S.表示 (y/n)
KEY_LOGSELECT = 'Loglevel'                              #               ログ表示レベル (-1/0/1/2/3/4/5)

# 初期設定ファイル・オブフェクト
myyaml = my_yaml.YamlProcess(FACE_YAML_PATH)

# 設定値読み出し
def get_facefolder():
    return myyaml.load_section_key(FACE_REC_SET, KEY_FACE_FOLDER)
def get_tolerance():
    return myyaml.load_section_key(FACE_REC_SET, KEY_TOLERANCE)
def get_titleflg():
    return myyaml.load_section_key(FACE_REC_SET, KEY_TILE_FLG)
def get_speedflg():
    return myyaml.load_section_key(FACE_REC_SET, KEY_SPEED_FLG)
def get_loglevel():
    return myyaml.load_section_key(FACE_REC_SET, KEY_LOGSELECT)

def get_uart_enable():
    return myyaml.load_section_key(UART_SET, KEY_ENABLE)
def get_uart_port():
    return myyaml.load_section_key(UART_SET, KEY_PORT)

def get_jtalk_enable():
    return myyaml.load_section_key(JTALK_SET, KEY_ENABLE)
def get_jtalk_voice():
    return myyaml.load_section_key(JTALK_SET, KEY_VOICE)

def get_mail_enable():
    return myyaml.load_section_key(MAIL_SET, KEY_ENABLE)
def get_mail_account():
    return myyaml.load_section_key(MAIL_SET, KEY_ACCOUNT)
def get_mail_password():
    return myyaml.load_section_key(MAIL_SET, KEY_PASSWORD)
def get_mail_host():
    return myyaml.load_section_key(MAIL_SET, KEY_HOST)
def get_mail_port():
    return myyaml.load_section_key(MAIL_SET, KEY_PORT)
def get_mail_from():
    return myyaml.load_section_key(MAIL_SET, KEY_FROM)
def get_mail_to():
    return myyaml.load_section_key(MAIL_SET, KEY_TO)

# 設定値書き込み
def set_facefolder(facefol):
    myyaml.write_append_key(FACE_REC_SET, KEY_FACE_FOLDER, facefol)
def set_tolerance(toler):
    myyaml.write_append_key(FACE_REC_SET, KEY_TOLERANCE, toler)
def set_titleflg(titleflg):
    myyaml.write_append_key(FACE_REC_SET, KEY_TILE_FLG, titleflg)
def set_speedflg(speedflg):
    myyaml.write_append_key(FACE_REC_SET, KEY_SPEED_FLG, speedflg)
def set_loglevel(logsel):
    myyaml.write_append_key(FACE_REC_SET, KEY_LOGSELECT, logsel)

def set_uart_enable(enbl):
    myyaml.write_append_key(UART_SET, KEY_ENABLE, enbl)
def set_uart_port(port):
    myyaml.write_append_key(UART_SET, KEY_PORT, port)

def set_jtalk_enable(enbl):
    myyaml.write_append_key(JTALK_SET, KEY_ENABLE, enbl)
def set_jtalk_voice(voice):
    myyaml.write_append_key(JTALK_SET, KEY_VOICE, voice)

def set_mail_enable(enbl):
    myyaml.write_append_key(MAIL_SET, KEY_ENABLE, enbl)
def set_mail_account(account):
    myyaml.write_append_key(MAIL_SET, KEY_ACCOUNT, account)
def set_mail_password(password):
    myyaml.write_append_key(MAIL_SET, KEY_PASSWORD, password)
def set_mail_host(host):
    myyaml.write_append_key(MAIL_SET, KEY_HOST, host)
def set_mail_port(port):
    myyaml.write_append_key(MAIL_SET, KEY_PORT, port)
def set_mail_from(from_email):
    myyaml.write_append_key(MAIL_SET, KEY_FROM, from_email)
def set_mail_to(to_email):
    myyaml.write_append_key(MAIL_SET, KEY_TO, to_email)

#-----Test routine-----
# $ python3 face_list.py
#
if __name__ == "__main__":
    # 設定を書き込む

    facefol = 'face_img'                            # face_rec
    set_facefolder(facefol)
    toler = '0.6'
    set_tolerance(toler)
    titleflg = 'y'
    set_titleflg(titleflg)
    speedflg = 'y'
    set_speedflg(speedflg)
    logsel = 3
    set_loglevel(logsel)

    enbl = 'No'                                     # UART
    set_uart_enable(enbl)
    port = '/dev/ttyUSB0'
    set_uart_port(port)

    enbl = 'Yes'                                     # OpenJTalk
    set_jtalk_enable(enbl)
    voice = 0
    set_jtalk_voice(voice)

    enbl = 'No'                                     # SMTP server
    set_mail_enable(enbl)
    account = 'aipromotion999@gmail.com'
    set_mail_account(account)
    password = 'alnxncjgkmrzxwua'
    set_mail_password(password)
    host = 'smtp.gmail.com'
    set_mail_host(host)
    port = 465
    set_mail_port(port)
    from_email = 'aipromotion999@gmail.com'
    set_mail_from(from_email)
    to_email = 'izutsum-sp@docomo.ne.jp'
    set_mail_to(to_email)

    # 設定を読み出す
    facefol = get_facefolder()
    print(f"Read '{FACE_REC_SET}' '{KEY_FACE_FOLDER}' : '{facefol}'", type(facefol))
    toler = get_tolerance()
    print(f"Read '{FACE_REC_SET}' '{KEY_TOLERANCE}' : '{toler}'", type(toler))
    titleflg = get_titleflg()
    print(f"Read '{FACE_REC_SET}' '{KEY_TILE_FLG}' : '{titleflg}'", type(titleflg))
    speedflg = get_speedflg()
    print(f"Read '{FACE_REC_SET}' '{KEY_SPEED_FLG}' : '{speedflg}'", type(speedflg))
    logsel = get_loglevel()
    print(f"Read '{FACE_REC_SET}' '{KEY_LOGSELECT}' : '{logsel}'", type(logsel))

    enbl = get_uart_enable()
    print(f"Read '{UART_SET}' '{KEY_ENABLE}' : '{enbl}'", type(enbl))
    port = get_uart_port()
    print(f"Read '{UART_SET}' '{KEY_PORT}' : '{port}'", type(port))

    enbl = get_jtalk_enable()
    print(f"Read '{JTALK_SET}' '{KEY_ENABLE}' : '{enbl}'", type(enbl))
    voice = get_jtalk_voice()
    print(f"Read '{JTALK_SET}' '{KEY_VOICE}' : '{voice}'", type(voice))

    enbl = get_mail_enable()
    print(f"Read '{MAIL_SET}' '{KEY_ENABLE}' : '{enbl}'", type(enbl))
    account = get_mail_account()
    print(f"Read '{MAIL_SET}' '{MAIL_SET}' : '{account}'", type(account))
    password = get_mail_password()
    print(f"Read '{MAIL_SET}' '{KEY_PASSWORD}' : '{password}'", type(password))
    host = get_mail_host()
    print(f"Read '{MAIL_SET}' '{KEY_HOST}' : '{host}'", type(host))
    port = get_mail_port()
    print(f"Read '{MAIL_SET}' '{KEY_PORT}' : '{port}'", type(port))
    from_email = get_mail_from()
    print(f"Read '{MAIL_SET}' '{KEY_FROM}' : '{from_email}'", type(from_email))
    to_email = get_mail_to()
    print(f"Read '{MAIL_SET}' '{KEY_TO}' : '{to_email}'", type(to_email))

