# -*- coding: utf-8 -*-
##------------------------------------------
##  My Library Send Mail by Python  Ver 0.01
##
##               2022.09.15 Masahiro Izutsu
##------------------------------------------
## my_mail.py

import ssl
from smtplib import SMTP, SMTP_SSL

from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.utils import formatdate

# MIME形式のメッセージ作成
#   from_email: メールの送り主
#   to_email:   メール送信先
#   message:    メール本文
#   subject:    メール・タイトル
#   filepath:   添付ファイルパス
#   filename:   添付ファイル名 
#
def createMIMEText(from_email, to_email, message, subject, filepath = None, filename = ""):
    # MIMETextを作成
    msg = MIMEMultipart()
    msg['Subject'] = subject
    msg['From'] = from_email
    msg['To'] = to_email
    msg.attach(MIMEText(message, 'plain', 'utf-8'))

    # 添付ファイルの設定
    if filepath:
        path = filepath
        with open(path, 'r') as fp:
            attach_file = MIMEText(fp.read(), 'plain')
            attach_file.add_header(
                "Content-Disposition", 
                "attachment", 
                filename=filename
            )
            msg.attach(attach_file)
    return msg

# メール送信
#   msg:        MIME形式メッセージ   
#   account:    アカウント
#   password:   パスワード
#   host:       SMTPサーバー名
#   port:       SMTPポート番号
#
def send_email(msg, account, password, host, port):
    # サーバを指定する
    # server = SMTP(host, port)
    context = ssl.create_default_context()
    server = SMTP_SSL(host, port, context=context)

    # ログイン処理
    server.login(account, password)

    # メールを送信する
    server.send_message(msg)
    
    # 閉じる
    server.quit()


if __name__ == '__main__':
    import my_logging
    import my_yaml
    import socket
    from os.path import expanduser

    logselm = 1
    loggerm = my_logging.get_module_logger_sel(__name__, logselm)

    FILE_PATH = expanduser('./test.yaml')
    MAIL_SET = 'MailServer'
    KEY_ACCOUNT = 'account'
    KEY_PASSWORD = 'password'
    KEY_HOST = 'host'
    KEY_PORT = 'port'
    KEY_FROM = 'from'
    KEY_TO ='to'

    myyaml = my_yaml.YamlProcess(FILE_PATH)
    account = myyaml.load_section_key(MAIL_SET, KEY_ACCOUNT)
    password = myyaml.load_section_key(MAIL_SET, KEY_PASSWORD)
    host = myyaml.load_section_key(MAIL_SET, KEY_HOST)
    port = myyaml.load_section_key(MAIL_SET, KEY_PORT)
    from_email = myyaml.load_section_key(MAIL_SET, KEY_FROM)
    to_email = myyaml.load_section_key(MAIL_SET, KEY_TO)

    loggerm.debug(f"{MAIL_SET} {KEY_ACCOUNT} : '{account}'")
    loggerm.debug(f"{MAIL_SET} {KEY_PASSWORD} : '{password}'")
    loggerm.debug(f"{MAIL_SET} {KEY_HOST} : '{host}'")
    loggerm.debug(f"{MAIL_SET} {KEY_PORT} : '{port}'")
    loggerm.debug(f"{MAIL_SET} {KEY_FROM} : '{from_email}'")
    loggerm.debug(f"{MAIL_SET} {KEY_TO} : '{to_email}'")

    hostname = socket.gethostname()
    subject = "メールのテスト１２"
    message = f"Python によるメール送信のテスト【その２】です\nhostname : {hostname}\nfrom : {from_email}\nto : {to_email}"

    loggerm.info(f"subject : '{subject}'")
    loggerm.info(f"message : '{message}'")

    # MIME形式の作成
    mime = createMIMEText(from_email, to_email, message, subject)

    # メールの送信
    send_email(mime, account, password, host, port)

