# -*- coding: utf-8 -*-
##------------------------------------------
##   Face Recognition result   ver 0.01
##      ～顔認証結果の処理サンプル～
##          platform: linux / windows
##
##               2022.09.14 Masahiro Izutsu
##------------------------------------------
## rec_result.py

import my_csv
import platform
import datetime
import my_mail
import face_rec_yaml

if platform.system()=='Windows':
    import jtalkw as jtalk
else:
    import jtalk

# 定数定義
LIST_FILE = 'face_img/facelist2.txt'

def get_kana(name):
    my_csv_treatment = my_csv.CSVtreatment(LIST_FILE)
    list1, list2, list3 = my_csv_treatment.read_list3_csv()
    kana = ''
    n = len(list1)
    if n > 0 and len(list2) > 0 and len(list3) > 0:
        for i in range(n):
            if name == list2[i]:
                kana = list3[i]
                break
    return kana

def get_speak_string(name):
    kana = get_kana(name)
    if len(kana) == 0:
        kana = name
    s = f'{kana}様　いらっしゃいませ' if len(kana) > 0 else ''
    return s

def speak_welcom(name, voice = 0, waitf = False):
    s = get_speak_string(name)
    jtalk.jtalk(s, voice, waitf) 

# 顔認証結果の処理（例）
#   in:     name                顔認証した名前
#           time                顔認証した時刻
#           logger              ログ出力オブジェクト
#
def recognition_result(name, time, logger):
    import socket

    hostname = socket.gethostname()

    # 受付音声
    jtalk_enbl = face_rec_yaml.get_jtalk_enable()               # JTalk 許可フラグ
    voice = face_rec_yaml.get_jtalk_voice()
    s = get_speak_string(name)
    logger.debug(s)
    if jtalk_enbl == 'Yes':
        jtalk.jtalk(s, voice, True) 

    d = datetime.datetime.strptime(time, '%Y/%m/%d %H:%M:%S')
    s = '%s月%s日、%s時%s分%s秒' % (d.month, d.day, d.hour, d.minute, d.second)
    logger.debug(s)
    if jtalk_enbl == 'Yes':
        jtalk.jtalk(s, voice) 

    # メール送信
    mail_enbl = face_rec_yaml.get_mail_enable()                 # メール送信許可フラグ
    logger.debug(f"e-mail : '{mail_enbl}'\n")

    if mail_enbl == 'Yes':
        account = face_rec_yaml.get_mail_account()
        password = face_rec_yaml.get_mail_password()
        host = face_rec_yaml.get_mail_host()
        port = face_rec_yaml.get_mail_port()
        from_email = face_rec_yaml.get_mail_from()
        to_email = face_rec_yaml.get_mail_to()
        logger.debug(f"send e-mail to : '{to_email}'")
        subject = f'{time} : 受付'
        message = f'{name} 様 来社です\nhostname : {hostname}\nfrom : {from_email}\nto : {to_email}'
        logger.info(f"subject : '{subject}'")
        logger.info(f"message : '{message}'")

        mime = my_mail.createMIMEText(from_email, to_email, message, subject)
        my_mail.send_email(mime, account, password, host, port)

#-----Test routine-----
# $ python3 face_list.py
#
if __name__ == "__main__":
    import my_logging

    logsel = 1
    logger = my_logging.get_module_logger_sel(__name__, logsel)

    recognition_result('桶川 秀次', '2022/9/15 9:15:01', logger)

